/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.workbench.screens.guided.dtable.client.wizard.column.commons;

import java.util.Collection;

import org.drools.workbench.models.datamodel.rule.RuleModel;
import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
import org.drools.workbench.screens.guided.rule.client.editor.RuleModellerConfiguration;
import org.drools.workbench.screens.guided.rule.client.editor.plugin.RuleModellerActionPlugin;

public interface HasRuleModellerPage {

    RuleModel getRuleModel();

    Collection<RuleModellerActionPlugin> getRuleModellerActionPlugins();

    RuleModellerConfiguration getRuleModellerConfiguration();

    String getRuleModellerDescription();

    void setRuleModellerPageAsCompleted();

    Boolean isRuleModellerPageCompleted();

    GuidedDecisionTable52.TableFormat tableFormat();
}
